@@ -85,7 +85,7 @@ class KarakeepAPI:
     """
 
     # Version reflects the client library version, updated by bumpver
-    VERSION: str = "1.2.3"
+    VERSION: str = "1.3.1"
 
     def __init__(
         self,
@@ -757,6 +757,20 @@ class KarakeepAPI:
         note: Optional[str] = None,
         summary: Optional[str] = None,
         createdAt: Optional[str] = None,  # ISO 8601 format string
+        crawlPriority: Optional[Literal["low", "normal"]] = None,
+        importSessionId: Optional[str] = None,
+        source: Optional[
+            Literal[
+                "api",
+                "web",
+                "cli",
+                "mobile",
+                "extension",
+                "singlefile",
+                "rss",
+                "import",
+            ]
+        ] = None,
         # Link specific
         url: Optional[str] = None,
         precrawledArchiveId: Optional[str] = None,
@@ -781,6 +795,9 @@ class KarakeepAPI:
             note: Optional note content for the bookmark.
             summary: Optional summary content for the bookmark.
             createdAt: Optional creation timestamp override (ISO 8601 format string).
+            crawlPriority: Optional either 'low' or 'normal'.
+            importSessionId: Optional import session ID for tracking imported bookmarks.
+            source: Optional source of the bookmark ("api", "web", "cli", "mobile", "extension", "singlefile", "rss", "import").
 
             --- Link Type Specific ---
             url: The URL for the link bookmark. Required if type='link'.
@@ -797,7 +814,9 @@ class KarakeepAPI:
             sourceUrl: Optional source URL where the asset originated.
 
         Returns:
-            datatypes.Bookmark: The created bookmark.
+            datatypes.Bookmark: The bookmark object.
+                               Returns with status 200 if the bookmark already exists,
+                               or status 201 if the bookmark was newly created.
             If response validation is disabled, returns the raw API response (dict/list).
 
         Raises:
@@ -821,6 +840,12 @@ class KarakeepAPI:
             request_body["summary"] = summary
         if createdAt is not None:
             request_body["createdAt"] = createdAt
+        if crawlPriority is not None:
+            request_body["crawlPriority"] = crawlPriority
+        if importSessionId is not None:
+            request_body["importSessionId"] = importSessionId
+        if source is not None:
+            request_body["source"] = source
 
         # Add type-specific fields and perform validation
         if type == "link":
@@ -907,7 +932,9 @@ class KarakeepAPI:
 
     @optional_typecheck
     def get_a_single_bookmark(
-        self, bookmark_id: str, include_content: bool = True  # Default from spec
+        self,
+        bookmark_id: str,
+        include_content: bool = True,  # Default from spec
     ) -> Union[datatypes.Bookmark, Dict[str, Any], List[Any]]:
         """
         Get a single bookmark by its ID. Corresponds to GET /bookmarks/{bookmarkId}.
@@ -1165,6 +1192,54 @@ class KarakeepAPI:
         # No Pydantic validation applied here as the spec defines a simple dict response
         return response_data
 
+    @optional_typecheck
+    def get_lists_of_a_bookmark(
+        self, bookmark_id: str
+    ) -> Union[List[datatypes.ListModel], Dict[str, Any], List[Any]]:
+        """
+        Get all lists associated with a specific bookmark. Corresponds to GET /bookmarks/{bookmarkId}/lists.
+
+        Args:
+            bookmark_id: The ID (string) of the bookmark.
+
+        Returns:
+            List[datatypes.ListModel]: A list of list objects associated with the bookmark.
+            If response validation is disabled, returns the raw API response (dict/list).
+
+        Raises:
+            APIError: If the API request fails (e.g., 404 bookmark not found).
+            pydantic.ValidationError: If response validation fails (and is not disabled).
+        """
+        endpoint = f"bookmarks/{bookmark_id}/lists"
+        response_data = self._call("GET", endpoint)
+
+        if self.disable_response_validation:
+            logger.debug("Skipping response validation as requested.")
+            # Return raw data, which might be {"lists": [...]} or something else
+            return response_data
+        else:
+            # Response schema is {"lists": [ListModel]}, extract the list and validate
+            if (
+                isinstance(response_data, dict)
+                and "lists" in response_data
+                and isinstance(response_data["lists"], list)
+            ):
+                try:
+                    return [
+                        datatypes.ListModel.model_validate(lst)
+                        for lst in response_data["lists"]
+                    ]
+                except (
+                    Exception
+                ) as e:  # Catch validation errors during list comprehension
+                    logger.error(f"Validation failed for one or more lists: {e}")
+                    raise  # Re-raise the validation error
+            else:
+                # Raise error if format is unexpected and validation is enabled
+                raise APIError(
+                    f"Unexpected response format for get_lists_of_a_bookmark when validation is enabled: {response_data}"
+                )
+
     @optional_typecheck
     def get_highlights_of_a_bookmark(
         self, bookmark_id: str
@@ -1361,7 +1436,7 @@ class KarakeepAPI:
         Create a new list (manual or smart). Corresponds to POST /lists.
 
         Args:
-            name: The name of the list (required, max 40 characters).
+            name: The name of the list (required, max 100 characters).
             icon: The icon for the list (required).
             description: Optional description for the list (max 100 characters).
             parent_id: Optional parent list ID for nested lists.
@@ -1470,8 +1545,8 @@ class KarakeepAPI:
 
         Args:
             list_id: The ID (string) of the list to update.
-            name: Optional new name for the list (1-40 characters).
-            description: Optional new description for the list (0-100 characters, can be None to clear).
+            name: Optional new name for the list (1-100 characters).
+            description: Optional new description for the list (0-500 characters, can be None to clear).
             icon: Optional new icon for the list.
             parent_id: Optional new parent list ID (can be None to remove parent relationship).
             query: Optional new query string for smart lists (minimum 1 character).
@@ -1597,46 +1672,47 @@ class KarakeepAPI:
         return None  # Explicitly return None for 204
 
     @optional_typecheck
-    def get_all_tags(self) -> Union[List[datatypes.Tag], Dict[str, Any], List[Any]]:
+    def get_all_tags(
+        self,
+        name_contains: Optional[str] = None,
+        sort: Optional[Literal["name", "usage", "relevance"]] = None,
+        attached_by: Optional[Literal["ai", "human", "none"]] = None,
+        cursor: Optional[str] = None,
+        limit: Optional[int] = None,
+    ) -> Union[datatypes.PaginatedTags, Dict[str, Any], List[Any]]:
         """
         Get all tags for the current user. Corresponds to GET /tags.
 
+        Args:
+            name_contains: Filter tags by name substring (optional).
+            sort: Sort order for tags ("name", "usage", "relevance"). Default from API is "usage" (optional).
+            attached_by: Filter tags by how they were attached ("ai", "human", "none") (optional).
+            cursor: Pagination cursor for the next page (optional).
+            limit: Maximum number of tags to return (optional).
+
         Returns:
-            List[datatypes.Tag]: A list of tag objects, including bookmark counts.
+            datatypes.PaginatedTags: Paginated list of tags with nextCursor for pagination.
             If response validation is disabled, returns the raw API response (dict/list).
 
         Raises:
             APIError: If the API request fails.
             pydantic.ValidationError: If response validation fails (and is not disabled).
         """
-        response_data = self._call("GET", "tags")
+        params = {
+            "nameContains": name_contains,
+            "sort": sort,
+            "attachedBy": attached_by,
+            "cursor": cursor,
+            "limit": limit,
+        }
+        response_data = self._call("GET", "tags", params=params)
 
         if self.disable_response_validation:
             logger.debug("Skipping response validation as requested.")
-            # Return raw data, which might be {"tags": [...]} or something else
             return response_data
         else:
-            # Response schema is {"tags": [Tag]}, extract the list and validate
-            if (
-                isinstance(response_data, dict)
-                and "tags" in response_data
-                and isinstance(response_data["tags"], list)
-            ):
-                try:
-                    return [
-                        datatypes.Tag.model_validate(tag)
-                        for tag in response_data["tags"]
-                    ]
-                except (
-                    Exception
-                ) as e:  # Catch validation errors during list comprehension
-                    logger.error(f"Validation failed for one or more tags: {e}")
-                    raise  # Re-raise the validation error
-            else:
-                # Raise error if format is unexpected and validation is enabled
-                raise APIError(
-                    f"Unexpected response format for get_all_tags when validation is enabled: {response_data}"
-                )
+            # Response should match PaginatedTags schema
+            return datatypes.PaginatedTags.model_validate(response_data)
 
     @optional_typecheck
     def create_a_new_tag(self, name: str) -> Dict[str, Any]:
@@ -1966,7 +2042,7 @@ class KarakeepAPI:
         Get information about the current authenticated user. Corresponds to GET /users/me.
 
         Returns:
-            dict: A dictionary containing user information ('id', 'name', 'email').
+            dict: A dictionary containing user information ('id', 'name', 'email', 'localUser').
                   Validation is not performed on this response type by default.
 
         Raises:
@@ -1992,6 +2068,57 @@ class KarakeepAPI:
         # No Pydantic validation applied here as the spec defines a simple dict response
         return response_data
 
+    @optional_typecheck
+    def update_user(
+        self,
+        user_id: str,
+        role: Optional[Literal["user", "admin"]] = None,
+        bookmark_quota: Optional[int] = None,
+        storage_quota: Optional[int] = None,
+        browser_crawling_enabled: Optional[bool] = None,
+    ) -> Dict[str, Any]:
+        """
+        Update a user's role, bookmark quota, or storage quota. Admin access required.
+        Corresponds to PUT /admin/users/{userId}.
+
+        Args:
+            user_id: The ID of the user to update.
+            role: Optional new role for the user ("user", "admin").
+            bookmark_quota: Optional new bookmark quota (minimum 0, can be None for unlimited).
+            storage_quota: Optional new storage quota in bytes (minimum 0, can be None for unlimited).
+            browser_crawling_enabled: Optional boolean to enable/disable browser crawling for the user.
+
+        Returns:
+            dict: A dictionary containing success status.
+                  Example: `{"success": True}`
+                  Validation is not performed on this response type by default.
+
+        Raises:
+            ValueError: If no fields are provided to update.
+            APIError: If the API request fails (e.g., 400 bad request, 401 unauthorized, 403 forbidden, 404 user not found).
+        """
+        # Construct update_data from provided arguments, excluding None values
+        update_data = {}
+        if role is not None:
+            update_data["role"] = role
+        if bookmark_quota is not None:
+            update_data["bookmarkQuota"] = bookmark_quota
+        if storage_quota is not None:
+            update_data["storageQuota"] = storage_quota
+        if browser_crawling_enabled is not None:
+            update_data["browserCrawlingEnabled"] = browser_crawling_enabled
+
+        # Ensure at least one field is being updated
+        if not update_data:
+            raise ValueError("At least one field must be provided to update.")
+
+        endpoint = f"admin/users/{user_id}"
+        response_data = self._call("PUT", endpoint, data=update_data)
+
+        # Response schema is a simple dict with success field, return as dict
+        # No Pydantic validation applied here as the spec defines a simple dict response
+        return response_data
+
     @optional_typecheck
     def upload_a_new_asset(
         self, file: str
